==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/TASKPLANPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TASKPLANPARTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TASKPLANPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPLANPARTID_Type", propOrder = {
    "tasklistid",
    "partlinenumber",
    "jobplanid"
})
public class TASKPLANPARTID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "PARTLINENUMBER")
    protected long partlinenumber;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Obtient la valeur de la propriété tasklistid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Définit la valeur de la propriété tasklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Obtient la valeur de la propriété partlinenumber.
     * 
     */
    public long getPARTLINENUMBER() {
        return partlinenumber;
    }

    /**
     * Définit la valeur de la propriété partlinenumber.
     * 
     */
    public void setPARTLINENUMBER(long value) {
        this.partlinenumber = value;
    }

    /**
     * Obtient la valeur de la propriété jobplanid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Définit la valeur de la propriété jobplanid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TASKPLANPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKPLANPARTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKPLANPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPLANPARTID_Type", propOrder = {
    "tasklistid",
    "partlinenumber",
    "jobplanid"
})
public class TASKPLANPARTID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "PARTLINENUMBER")
    protected long partlinenumber;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Gets the value of the tasklistid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Sets the value of the tasklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Gets the value of the partlinenumber property.
     * 
     */
    public long getPARTLINENUMBER() {
        return partlinenumber;
    }

    /**
     * Sets the value of the partlinenumber property.
     * 
     */
    public void setPARTLINENUMBER(long value) {
        this.partlinenumber = value;
    }

    /**
     * Gets the value of the jobplanid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Sets the value of the jobplanid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}
